@@ -4,9 +4,9 @@
 import json, os, sys
 from datetime import *
 from nkit4py import Xml2VarBuilder
-import copy
 
 
+# ------------------------------------------------------------------------------
 class DatetimeEncoder(json.JSONEncoder):
     def default( self, obj ):
         if isinstance( obj, datetime ):
@@ -30,15 +30,16 @@ def pring_json(v):
 
 path = os.path.dirname(os.path.realpath(__file__))
 
-xml_path = path + "/data/sample.xml";
+xml_path = path + "/data/sample.xml"
 f2 = open( xml_path, 'r' )
 xmlString = f2.read()
 
+# ------------------------------------------------------------------------------
 # Here mapping is list, described by '/path/to/element' and list-item-description.
 # List item here is a 'string' scalar.
 # Scalar definition contains type name and optional default value.
-mapping = '["/person/phone", "string"]';
-# mapping = '["/person/phone", "string|optionalDefaultValue"]';
+mapping = '["/person/phone", "string"]'
+# mapping = '["/person/phone", "string|optionalDefaultValue"]'
 
 builder = Xml2VarBuilder(mapping)
 builder.feed(xmlString)
@@ -47,7 +48,7 @@ result = builder.end()
 etalon = [ '+122233344550',
            '+122233344551',
            '+122233344553',
-           '+122233344554' ];
+           '+122233344554']
 
 if result != etalon:
     pring_json(result)
@@ -80,14 +81,14 @@ result = builder.end()
 #  Here mapping is list, described by /path/to/element and list item
 #  description. List item is described as 'list' sub-mapping, described 
 #  by sub-path and'string' scalar definition
-mapping = '["/person", ["/phone", "string"]]';
+mapping = '["/person", ["/phone", "string"]]'
 
-builder = Xml2VarBuilder(mapping);
-builder.feed(xmlString); # can be more than one call to feed(xmlChunk) method
-result = builder.end();
+builder = Xml2VarBuilder(mapping)
+builder.feed(xmlString) # can be more than one call to feed(xmlChunk) method
+result = builder.end()
 
-etalon = [ [ '+122233344550', '+122233344551' ],
-    [ '+122233344553', '+122233344554' ] ];
+etalon = [ [ '+122233344550', '+122233344551'],
+    [ '+122233344553', '+122233344554']]
 
 if result != etalon:
     pring_json(result)
@@ -118,9 +119,9 @@ mapping = """["/person",
     }
 ]"""
 
-builder = Xml2VarBuilder(mapping);
-builder.feed(xmlString); # can be more than one call to feed(xmlChunk) method
-result = builder.end();
+builder = Xml2VarBuilder(mapping)
+builder.feed(xmlString) # can be more than one call to feed(xmlChunk) method
+result = builder.end()
 
 etalon = [
     {
@@ -137,7 +138,7 @@ etalon = [
         "birthday": datetime(1970, 8, 31, 2, 3, 4),
         "cities": [ 'Moscow', 'Tula' ],
     }
-];
+]
 
 if result != etalon:
     pring_json(result)
@@ -145,5 +146,71 @@ if result != etalon:
     print "Error #3"
     sys.exit(1)
 
-print "ok";
-sys.exit(0);
+# ------------------------------------------------------------------------------
+mapping = """["/person",
+    {
+        "/*": "string"
+    }
+]"""
+
+builder = Xml2VarBuilder(mapping)
+builder.feed(xmlString) # can be more than one call to feed(xmlChunk) method
+result = builder.end()
+
+etalon = [
+  {
+    "name": "Jack",
+    "photos": "\n\t\t\t\n\t\t\t\n\t\t\t\n\t\t",
+    "age": "33",
+    "married": "Yes",
+    "phone": "+122233344551",
+    "birthday": "Wed, 28 Mar 1979 12:13:14 +0300",
+    "address": "\n\t\t\t\n\t\t\t\n\t\t\t\n\t\t\t\n\t\t"
+  },
+  {
+    "name": "Boris",
+    "photos": "\n\t\t\t\n\t\t\t\n\t\t",
+    "age": "34",
+    "married": "Yes",
+    "phone": "+122233344554",
+    "birthday": "Mon, 31 Aug 1970 02:03:04 +0300",
+    "address": "\n\t\t\t\n\t\t\t\n\t\t\t\n\t\t\t\n\t\t"
+  }
+]
+
+if result != etalon:
+    pring_json(result)
+    pring_json(etalon)
+    print "Error #4"
+    sys.exit(1)
+
+
+# ------------------------------------------------------------------------------
+mapping = """["/person", {
+   	"/key_for_default_value": "string|default_value",
+    "/non_existing_key": "string"
+    }
+]"""
+
+builder = Xml2VarBuilder(mapping)
+builder.feed(xmlString) # can be more than one call to feed(xmlChunk) method
+result = builder.end()
+
+etalon = [
+  {
+    "key_for_default_value": "default_value"
+  },
+  {
+    "key_for_default_value": "default_value"
+  }
+]
+
+if result != etalon:
+    pring_json(result)
+    pring_json(etalon)
+    print "Error #4"
+    sys.exit(1)
+
+
+print "ok"
+sys.exit(0)
